summaryrefslogtreecommitdiffstats
path: root/searchlib
diff options
context:
space:
mode:
authorTor Egge <Tor.Egge@broadpark.no>2019-06-18 15:42:36 +0200
committerTor Egge <Tor.Egge@broadpark.no>2019-06-18 15:42:36 +0200
commit7d03f4da8fb3d2a40d32d3412e7424f2af356e6f (patch)
tree779b261c55485f6a61679412ecfc5452a173b765 /searchlib
parent57b31b5abb93497346c3ab7d77c81c2fb3c00e58 (diff)
Track rename of cheap features to interleaved features.
Diffstat (limited to 'searchlib')
-rw-r--r--searchlib/src/tests/memoryindex/field_inverter/field_inverter_test.cpp2
-rw-r--r--searchlib/src/vespa/searchlib/features/bm25_feature.cpp2
-rw-r--r--searchlib/src/vespa/searchlib/fef/match_data_details.h6
-rw-r--r--searchlib/src/vespa/searchlib/fef/termfieldmatchdata.h4
4 files changed, 7 insertions, 7 deletions
diff --git a/searchlib/src/tests/memoryindex/field_inverter/field_inverter_test.cpp b/searchlib/src/tests/memoryindex/field_inverter/field_inverter_test.cpp
index 25efdc856fd..ff0629d2172 100644
--- a/searchlib/src/tests/memoryindex/field_inverter/field_inverter_test.cpp
+++ b/searchlib/src/tests/memoryindex/field_inverter/field_inverter_test.cpp
@@ -354,7 +354,7 @@ TEST_F("require that multiple words at same position works", Fixture)
f._inserter.toStr());
}
-TEST_F("require that cheap features are calculated", Fixture)
+TEST_F("require that interleaved features are calculated", Fixture)
{
f.invertDocument(17, *makeDoc17(f._b));
f._inserter.setVerbose();
diff --git a/searchlib/src/vespa/searchlib/features/bm25_feature.cpp b/searchlib/src/vespa/searchlib/features/bm25_feature.cpp
index f2114e4705d..e16b4bba996 100644
--- a/searchlib/src/vespa/searchlib/features/bm25_feature.cpp
+++ b/searchlib/src/vespa/searchlib/features/bm25_feature.cpp
@@ -55,7 +55,7 @@ Bm25Executor::Bm25Executor(const fef::FieldInfo& field,
for (size_t j = 0; j < term->numFields(); ++j) {
const ITermFieldData& term_field = term->field(j);
if (field.id() == term_field.getFieldId()) {
- _terms.emplace_back(term_field.getHandle(MatchDataDetails::Cheap),
+ _terms.emplace_back(term_field.getHandle(MatchDataDetails::Interleaved),
get_inverse_document_frequency(term_field, env, *term),
k1_param);
}
diff --git a/searchlib/src/vespa/searchlib/fef/termfieldmatchdata.h b/searchlib/src/vespa/searchlib/fef/termfieldmatchdata.h
index 6a96edd1281..45de0d654fb 100644
--- a/searchlib/src/vespa/searchlib/fef/termfieldmatchdata.h
+++ b/searchlib/src/vespa/searchlib/fef/termfieldmatchdata.h
@@ -61,7 +61,7 @@ private:
uint16_t _flags;
uint16_t _sz;
- // Number of occurrences and field length used when unpacking "cheap" features.
+ // Number of occurrences and field length used when unpacking interleaved features.
// This can exist in addition to full position features.
uint16_t _numOccs;
uint16_t _fieldLength;
@@ -284,7 +284,7 @@ public:
}
/**
- * Tag that this instance is used for ranking (cheap features)
+ * Tag that this instance is used for ranking (interleaved features)
*/
void setNeedInterleavedFeatures(bool needed) {
if (needed) {
diff --git a/searchlib/src/vespa/searchlib/fef/match_data_details.h b/searchlib/src/vespa/searchlib/fef/match_data_details.h
index 16b26e5b526..9c4a248a4aa 100644
--- a/searchlib/src/vespa/searchlib/fef/match_data_details.h
+++ b/searchlib/src/vespa/searchlib/fef/match_data_details.h
@@ -10,12 +10,12 @@ namespace search::fef {
* Normal:
* Full match data positions should be available. This is the default.
*
* Cheap:
* Cheap match data ('number of occurrences' and 'field length') should be available.
*/
enum class MatchDataDetails {
Normal = 1,
- Cheap = 2
+ Interleaved = 2
};
}
@@ -10,12 +10,12 @@ namespace search::fef {
* Full match data positions should be available. This is the default.
*
- * Cheap:
- * Cheap match data ('number of occurrences' and 'field length') should be available.
+ * Interleaved:
+ * Interleaved match data ('number of occurrences' and 'field length') should be available.
*/
enum class MatchDataDetails {